import random as r
from math import *
import argparse

args = argparse.ArgumentParser()
args.add_argument('--size', default=10, type=float, help='max size of input')
args.add_argument('--range', default=20, type=int, help='max absolute value of coordinates')
subargs = args.add_subparsers(dest='type', help='testcase generator')
subargs.add_parser('box')
subargs.add_parser('sphere')
subargs.add_parser('ball')
line_args = subargs.add_parser('line')
line_args.add_argument('--width', default=0, type=int)
line_args.add_argument('dx', type=int)
line_args.add_argument('dy', type=int)
subargs.add_parser('fractal')
subargs.add_parser('singular')
args = args.parse_args()

n = r.randint(args.size*0.9, args.size)
print(n)

if args.type == 'box':
	for _ in range(n):
		print(r.randint(-args.range, args.range), r.randint(-args.range, args.range))
elif args.type == 'sphere':
	for _ in range(n):
		theta = r.random()*tau
		print(int(args.range*cos(theta)), int(args.range*sin(theta)))
elif args.type == 'ball':
	for _ in range(n):
		theta = r.random()*tau
		a = args.range*(r.random()**0.5)
		print(int(a*cos(theta)), int(a*sin(theta)))
elif args.type == 'line':
	scale = args.range/max(args.dx, args.dy)
	for _ in range(n):
		t = int((r.random()*2-1) * scale)
		print(t*args.dx + r.randint(0, args.width), t*args.dy)
elif args.type == 'fractal':
	def gen(i, x1, y1, x2, y2):
		if i <= 0:
			yield (x1, y1)
		else:
			x12 = (x1 + x2 + y2 - y1)*0.5
			y12 = (y1 + y2 - x2 + x1)*0.5
			if i > 16:
				x12, y12 = y12, x12
			yield from gen(i-1, x1, y1, x12, y12)
			yield from gen(i-1, x12, y12, x2, y2)
	pts = list(gen(18, r.random(), r.random(), r.random(), r.random()))
	r.shuffle(pts)
	for x, y in pts[:n]:
		print(int(args.range*x), int(args.range*y))
elif args.type == 'singular':
	x = int(r.randint(-args.range, args.range))
	y = int(r.randint(-args.range, args.range))
	for _ in range(n):
		print(x, y)
else:
	raise ValueError('generator type')
