#!/bin/sh -e

time=$(which gtime || which time) # want GNU time, not BSD time
testcnt_file=$(mktemp)
trap 'rm $testcnt_file' EXIT
echo 0 > $testcnt_file

rm -f input/*.txt
rm -f gen/GEN

new_group() {
	echo "# ST: $1" >> gen/GEN
}

new_test() {
	test_i=$(cat $testcnt_file)
	echo "$test_i $@" >> gen/GEN
	echo input/input$test_i.txt
	expr $test_i + 1 > $testcnt_file
}

new_group 0
cp sample/sample1.txt $(new_test example)
cp sample/sample2.txt $(new_test example)

gen_test() {
	echo "generating $@..." >&2
	#name=$(echo "$*" | sed 's/[^a-z0-9]/_/g')
	python3 ./gen/gen.py "$@" > $(new_test "$*")
}

gen_basic() {
	gen_test "$@" box
	gen_test "$@" sphere
	gen_test "$@" ball
	gen_test "$@" line 2 3
	gen_test "$@" line --width 1 0 1
	gen_test "$@" line --width 1 1 1
	gen_test "$@" line --width 5 1 1
	gen_test "$@" line --width 1 2 3
	gen_test "$@" fractal
	gen_test "$@" singular
}

gen_rtest() {
	for _ in $(seq 3)
	do
		./gen/rtest.sh\
			'python3 ./sol/sol.py'\
			./sol/build-opt/cpp_bug_hull\
			--size 100 --range 100000000 line --width 3 1 1\
		> $(new_test rtest cpp_bug_hull)
		./gen/rtest.sh\
			'python3 ./sol/sol.py'\
			./sol/build-opt/cpp_gscan_32\
			--size 100 --range 100000000 line --width 3 1 1\
		> $(new_test rtest cpp_gscan_32)
	done
}

new_group 20
gen_basic --size 20 --range 1000
new_group 20
gen_basic --size 1000 --range 100000000
gen_rtest
new_group 20
gen_basic --size 100000 --range 100000000
gen_rtest

sed -i '' '/n_input is generated/d' task.yaml
echo "n_input: $(cat $testcnt_file) # n_input is generated" >> task.yaml

# sol.py
mkdir -p output
for input in $(ls input/*.txt | sort -V)
do
	output=output/output${input#input/input}
	$time -f "$input %U %M" python3 ./sol/sol.py < $input > $output
done

# sol.cpp
mkdir -p output_cpp
make -C sol/build-opt cpp
for input in $(ls input/input*.txt | sort -V)
do
	output=output_cpp/output${input#input/input}
	$time -f "$input %U %M" ./sol/build-opt/cpp < $input > $output
	cat output/output${input#input/input} $output | python3 sol/check.py
done

# sol.hs
mkdir -p output_hs
make -C sol/build-opt hs
for input in $(ls input/input*.txt | sort -V)
do
	output=output_hs/output${input#input/input}
	$time -f "$input %U %M" ./sol/build-opt/cpp < $input > $output
	cat output/output${input#input/input} $output | python3 sol/check.py
done
