import Debug.Trace (trace)
import Data.List (sortBy)
import Control.Applicative
import Control.Monad
import Data.Maybe

safe :: ([a] -> a) -> [a] -> Maybe a
safe _ [] = Nothing
safe f xs = Just $ f xs

debug :: Show a => String -> a -> a
--debug msg x = trace (msg++show x) x
debug _ = id

data V = V Double Double
  deriving (Eq, Show)

instance Num V where
  (V x1 y1) + (V x2 y2) = V (x1 + x2) (y1 + y2)
  (V x1 y1) * (V x2 y2) = V (x1 * x2) (y1 * y2)
  abs (V x y) = V (abs x) (abs y)
  signum (V x y) = V (signum x) (signum y)
  negate (V x y) = V (-x) (-y)
  fromInteger _ = undefined

cross :: V -> V -> Double
cross (V x1 y1) (V x2 y2) = x1*y2 - x2*y1

orient :: V -> V -> V -> Double
orient a p b = cross (a-p) (b-p)

scan :: [V] -> [V]
scan = aux []
  where
    aux xs [] = xs
    aux [] (y:ys) = aux [y] ys
    aux [x] (y:ys) = aux [y, x] ys
    aux (x1:x2:xs) (y:ys) | orient y x2 x1 >= 0 = aux (x2:xs) (y:ys)
    aux xs (y:ys) = aux (y:xs) ys

leftRight :: [V] -> ([V], [V])
leftRight pts = ((scan.reverse) pts', scan pts')
  where
    pts' = sortBy (\(V x1 y1) (V x2 y2) -> compare y1 y2 <> compare x1 x2) pts

trap :: Double -> V -> V -> Double -> Double
trap a (V x1 y1) (V x2 y2) b | a == b = 0
trap a (V x1 y1) (V x2 y2) b = (a-b)*x3
  where
    y3 = (a+b)*0.5
    x3 = x1 + (y3-y1)*dx/dy
    dx = x2 - x1
    dy = y2 - y1

pairs :: [a] -> [(a, a)]
pairs [_] = []
pairs (a:b:rest) = (a, b) : pairs (b:rest)

cover :: [V] -> Double
cover pts = fromMaybe 0 $ (-) <$> rS <*> lS
  where
    (lHull, rHull) = debug "lr: " $ leftRight pts
    V _ top = head lHull
    V _ bot = head rHull
    nonDegenerate (V _ y1, V _ y2) = y1 /= y2
    lengths = map (\(a, b) -> trap bot a b top) . filter nonDegenerate 
    rSides = lengths $ pairs rHull
    lSides = lengths $ pairs lHull
    rS :: Maybe Double
    lS :: Maybe Double
    rS = safe minimum $ rSides
    lS = safe maximum $ lSides

getPoint :: IO V
getPoint = parse <$> getLine
  where parse s = let [x, y] = map read $ words s in V x y

main :: IO ()
main = do
  n <- fmap read $ getLine
  pts <- replicateM n getPoint
  putStrLn $ show $ cover pts
