import sys
from fractions import Fraction
from decimal import Context

do_plot = 'plot' in sys.argv[1:]
if do_plot:
	import matplotlib
	import matplotlib.pyplot as plt
	matplotlib.use('gtk3agg')
	fig, axes = plt.subplots(figsize=(3, 3))

inp = iter(map(int, sys.stdin.read().split()))
n = next(inp)

pts = [(next(inp), next(inp)) for _ in range(n)]

def orient(a, o, b):
	ax, ay = a
	ox, oy = o
	bx, by = b
	return (ax-ox)*(by-oy) - (ay-oy)*(bx-ox)

def convex_hull(pts):
	def scan(pts):
		it = iter(pts)
		hull = [next(it)]
		for p in it:
			while len(hull) > 1 and orient(hull[-1], hull[-2], p) >= 0:
				hull.pop()
			hull.append(p)
		return hull
	pts.sort()
	up = scan(pts)
	pts.reverse()
	lo = scan(pts)
	assert lo[0] == up[-1]
	assert lo[-1] == up[0]
	return up + lo[1:-1]

def comp(xs, i):
	return list(map(lambda x: x[i], xs))

hull = convex_hull(pts)
sys.stderr.write(f'hull: {len(hull)} points\n')
sys.stderr.write(f'hull: {hull}\n')
hull.append(hull[0])

min_y = min(hull, key=lambda p: p[1])[1]
max_y = max(hull, key=lambda p: p[1])[1]
if min_y == max_y:
	print("0")
	sys.exit()
ls = -(1<<200)
rs = 1<<200
best_l = None
best_r = None
for i in range(len(hull)-1):
	ax, ay = hull[i+0]
	bx, by = hull[i+1]
	dx = bx-ax
	dy = by-ay
	if dy == 0:
		continue
	my = (min_y + max_y)
	denom = dy*2
	num = (max_y-min_y)*(ax*dy*2 + (my - ay*2)*dx)
	s = Fraction(num, denom)
	if ay < by:
		if s > ls:
			ls = s
			best_l = i
	else:
		if s < rs:
			rs = s
			best_r = i
ans = rs-ls
dec = Context(100)
print(dec.divide(ans.numerator, ans.denominator))
if do_plot:
	# chosen points
#	axes.plot([hull[best_l+0][0], hull[best_l+1][0]],\
#	          [hull[best_l+0][1], hull[best_l+1][1]], 
#		  'ro', markersize=12)
#	axes.plot([hull[best_r+0][0], hull[best_r+1][0]],\
#	          [hull[best_r+0][1], hull[best_r+1][1]], 
#		  'ro', markersize=12)

	# points
	axes.plot(comp(pts, 0), comp(pts, 1), 'o', color='black')

	# hull
#	axes.plot(comp(hull, 0), comp(hull, 1), 'b-')

	# the trapezoid
	def solve(p1, p2, y3):
		dx = p2[0]-p1[0]
		dy = p2[1]-p1[1]
		return p1[0]+(y3-p1[1])*dx/dy, y3
	a = solve(hull[best_l+0], hull[best_l+1], max_y)
	b = solve(hull[best_r+0], hull[best_r+1], max_y)
	c = solve(hull[best_r+0], hull[best_r+1], min_y)
	d = solve(hull[best_l+0], hull[best_l+1], min_y)
	t = [a, b, c, d, a]
	axes.plot(comp(t, 0), comp(t, 1), 'r-', lw=1)
	axes.fill(comp(t, 0), comp(t, 1), '#ff000030')
	
	fig.savefig('/tmp/fig.pdf')
	plt.show()
