#include <algorithm>
#include <vector>
#include <stdio.h>
#include <iostream>
#include <cassert>
using namespace std;

#define ran(i, a, b) for (auto i = (a); i < (b); i++)
using ll = long long;
using vi = vector<int>;
using ii = pair<int, int>;
#if defined(SHIROKO1_LOCAL) && !defined(NDEBUG)
#define DEBUG(x) cerr << x << endl;
#else
#define DEBUG(...) ((void)0)
#endif

struct pt {
	double x, y;
};

ostream &operator<<(ostream &o, const pt &p)
{ return o << p.x << ' ' << p.y; }

pt operator-(pt a, pt b) { return { a.x-b.x, a.y-b.y }; }

static ll cross(pt a, pt b)
{ return (ll)a.x*b.y - (ll)a.y*b.x; }

static ll orient(pt a, pt o, pt b)
{ return cross(a-o, b-o); }

static int convex_hull(int *hull, const pt *p, int n)
{
	ran (i, 0, n)
		hull[i] = i;
	int j = 0;
	ran (i, 1, n) {
		if (p[i].y < p[j].y || (p[i].y == p[j].y && p[i].x < p[j].x))
			j = i;
	}
	swap(hull[0], hull[j]);
	sort(hull+1, hull+n, [=](int a, int b) {
		// XXX: orient(...) == 0 is not handled!
		return orient(p[a], p[hull[0]], p[b]) < 0;
	});
	int k = 2;
	ran (i, 2, n) {
		while (k >= 2 && orient(p[hull[i]], p[hull[k-2]], p[hull[k-1]]) <= 0)
			k--;
		hull[k++] = hull[i];
	}
	return k;
}

static double trap(int top, int bot, pt a, pt b)
{
	double yh = (top+bot)*0.5;
	double dx = b.x-a.x;
	double dy = b.y-a.y;
	double xh = a.x + (yh-a.y)*dx/dy;
	double s = (top-bot)*xh;
	DEBUG("TRAP " << a << " -- " << b << " IS " << s);
	return s;
}

int main()
{
	int n;
	scanf("%i", &n);
	pt *p = new pt[n];
	ran (i, 0, n)
		scanf("%lf%lf", &p[i].x, &p[i].y);
	int *hull = new int[n+1];
	int k = convex_hull(hull, p, n);
	double max_y = p[0].y, min_y = p[0].y;
	ran (i, 1, n) {
		max_y = max(max_y, p[i].y);
		min_y = min(min_y, p[i].y);
	}
	if (max_y == min_y) {
		puts("0");
		return 0;
	}
	hull[k] = hull[0];
	double ls = -1.0/0.0, rs = 1.0/0.0;
	ran (i, 0, k) {
		pt a = p[hull[i]];
		pt b = p[hull[i+1]];
		if (a.y < b.y)
			ls = max(ls, trap(max_y, min_y, a, b));
		else if (b.y < a.y)
			rs = min(rs, trap(max_y, min_y, a, b));
	}
	printf("%.10lf\n", rs-ls);
	delete[] hull;
	delete[] p;
	return 0;
}
