#include <algorithm>
#include <vector>
#include <stdio.h>
#include <iostream>
#include <cassert>
using namespace std;

#define ran(i, a, b) for (auto i = (a); i < (b); i++)
using ll = long long;
using vi = vector<int>;
using ii = pair<int, int>;
#if defined(SHIROKO1_LOCAL) && !defined(NDEBUG)
#define DEBUG(x) cerr << x << endl;
#else
#define DEBUG(...) ((void)0)
#endif

struct pt {
	float x, y;
};

ostream &operator<<(ostream &o, const pt &p)
{ return o << '(' << p.x << ' ' << p.y << ')'; }

pt operator-(pt a, pt b) { return { a.x-b.x, a.y-b.y }; }

static float dot(pt a, pt b)
{ return a.x*b.x + a.y*b.y; }

static float dist2(pt a, pt b)
{ return dot(a-b, a-b); }

static float cross(pt a, pt b)
{ return a.x*b.y - a.y*b.x; }

static float orient(pt a, pt o, pt b)
{ return cross(a-o, b-o); }

static int convex_hull(int *hull, const pt *p, int n)
{
	ran (i, 0, n)
		hull[i] = i;
	int j = 0;
	ran (i, 1, n) {
		if (p[i].y < p[j].y || (p[i].y == p[j].y && p[i].x < p[j].x))
			j = i;
	}
	swap(hull[0], hull[j]);
	DEBUG("PIVOT " << p[hull[0]]);
	sort(hull+1, hull+n, [=](int a, int b) {
		auto o = orient(p[a], p[hull[0]], p[b]);
		if (o == 0.0) {
			return dist2(p[a], p[hull[0]]) < dist2(p[b], p[hull[0]]);
		}
		return o < 0;
	});
	int k = 2;
	DEBUG("PUSH " << p[hull[0]]);
	DEBUG("PUSH " << p[hull[1]]);
	ran (i, 2, n) {
		while (k >= 2) {
			float o = orient(p[hull[i]], p[hull[k-2]], p[hull[k-1]]);
			DEBUG("cross = " << o);
			if (o > 0)
				break;
			k--;
			DEBUG("POP " << p[hull[k]]);
		}
		DEBUG("PUSH " << p[hull[i]]);
		hull[k++] = hull[i];
	}
	return k;
}

static float trap(float top, float bot, pt a, pt b)
{
	float yh = (top+bot)*0.5;
	float dx = b.x-a.x;
	float dy = b.y-a.y;
	float xh = a.x + (yh-a.y)*dx/dy;
	float s = (top-bot)*xh;
	DEBUG("TRAP " << a << " -- " << b << " IS " << s);
	return s;
}

int main()
{
	int n;
	scanf("%i", &n);
	pt *p = new pt[n];
	ran (i, 0, n) {
		int x, y;
		scanf("%i%i", &x, &y);
		p[i].x = x;
		p[i].y = y;
	}
	int *hull = new int[n+1];
	int k = convex_hull(hull, p, n);
	float max_y = p[0].y, min_y = p[0].y;
	ran (i, 1, n) {
		max_y = max(max_y, p[i].y);
		min_y = min(min_y, p[i].y);
	}
	DEBUG("Y range: " << min_y << " " << max_y);
	if (max_y == min_y) {
		puts("0");
		return 0;
	}
	hull[k] = hull[0];
	float ls = -1.0/0.0, rs = 1.0/0.0;
	ran (i, 0, k) {
		pt a = p[hull[i]];
		pt b = p[hull[i+1]];
		float s = trap(max_y, min_y, a, b);
		if (a.y < b.y)
			ls = max(ls, s);
		else if (b.y < a.y)
			rs = min(rs, s);
	}
	printf("%.10lf\n", (float)(rs-ls));
	delete[] hull;
	delete[] p;
	return 0;
}
