#include <iostream>
#include <string>
#include <vector>
#include <algorithm>
#include <cassert>
#include <map>
#include <set>
#include <sstream>
#include <fstream>

using namespace std;

vector<string> parse_line (string line) {
  vector<string> tokens;
  istringstream ss (line);
  string token;
  while (ss >> token) {
    tokens.push_back(token);
  }
  return tokens;
}

bool is_ws (char c) {
  return c <= 32;
}

string cleanse (string str) {
  while (!str.empty() && is_ws(str.back())) {
    str.pop_back();
  }
  return str;
}

int main (int argc, char **argv) {
  ifstream input_file (argv[1]);
  ifstream answer_file (argv[2]);
  ifstream student_file (argv[3]);

  string can;
  answer_file >> can;
  answer_file.close();
  
  int vertexc, edgec;
  input_file >> vertexc >> edgec;

  vector<string> children_sorted (vertexc);
  map<string, int> degree;
  for (int i = 0; i < vertexc; i++) {
    input_file >> children_sorted[i];
    degree[children_sorted[i]] = 0;
  }
  sort(children_sorted.begin(), children_sorted.end());

  set<pair<string, string>> friends;
  for (int i = 0; i < edgec; i++) {
    string u, v;
    input_file >> u >> v;
    friends.insert(make_pair(u, v));
    friends.insert(make_pair(v, u));
    degree[u]++;
    degree[v]++;
  }

  vector<string> student_output;
  while (student_file) {
    string str;
    getline(student_file, str);
    student_output.push_back(str);
  }
  student_file.close();

  if (!student_output.empty() && student_output.back().empty()) {
    student_output.pop_back();
  }

  if (student_output.empty()) {
    cerr << "Presentation error: output is empty!" << endl;
    cout << "0.0" << endl;
    return 0;
  }

  student_output[0] = cleanse(student_output[0]);

  if (student_output[0] != "EI SAA" && student_output[0] != "SAAB") {
    cerr << "Presentation error: first line is not EI SAA or SAAB!" << endl;
    cout << "0.0" << endl;
    return 0;
  }

  if (student_output[0] == "EI SAA" && (int) student_output.size() != 1) {
    cerr << "Presentation error: first line is EI SAA but output is not 1 line!" << endl;
    cout << "0.0" << endl;
    return 0;
  }

  if (student_output[0] == "SAAB" && (int) student_output.size() != 2) {
    cerr << "Presentation error: first line is SAAB but output is not 2 lines!" << endl;
    cout << "0.0" << endl;
    return 0;
  }
  
  if (can == "EI") {
    if (student_output[0] == "SAAB") {
      cerr << "Wrong answer" << endl;
      cout << "0.0" << endl;
      return 0;
    } else {
      cerr << "OK" << endl;
      cout << "1.0" << endl;
      return 0;
    }
  } else if (can == "SAAB") {
    if (student_output[0] == "EI SAA") {
      cerr << "Wrong answer" << endl;
      cout << "0.0" << endl;
      return 0;
    } else {
      vector<string> row = parse_line(student_output[1]);
      if ((int) row.size() != vertexc) {
        cerr << "Presentation error: second line has invalid number of tokens!" << endl;
        cout << "0.0" << endl;
        return 0;
      }

      vector<string> row_sorted = row;
      sort(row_sorted.begin(), row_sorted.end());
      if (row_sorted != children_sorted) {
        cerr << "Presentation error: second line is not a permutation of the list of children!" << endl;
        cout << "0.0" << endl;
        return 0;
      }

      for (int i = 0; i < vertexc - 1; i++) {
        if (friends.count(make_pair(row[i], row[i + 1])) != 0) {
          degree[row[i]]--;
          degree[row[i + 1]]--;
        }
      }

      for (pair<string, int> pr : degree) {
        if (pr.second != 0) {
          cerr << "Wrong answer" << endl;
          cout << "0.0" << endl;
          return 0;
        }
      }

      cerr << "OK" << endl;
      cout << "1.0" << endl;
      return 0;
    }
  } else {
    assert(false);
  }
}
